@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.21.0";
+our $VERSION = "v6.22.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 88 of the 100+ operators in rxjs are implemented in this module.
+Currently 89 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -747,6 +747,21 @@ L<https://rxjs.dev/api/operators/first>
         op_first(),
     )->subscribe($observer);
 
+=item op_group_by
+
+L<https://rxjs.dev/api/operators/groupBy>
+
+    # [0, 2, 4], [1, 3], complete
+    rx_interval(0.7)->pipe(
+        op_take(5),
+        op_group_by(sub { $_[0] % 2 }), # can also use $_ here
+        op_merge_map(sub ($g, @) {
+            return $g->pipe(
+                op_reduce(sub ($acc, $cur) { [@$acc, $cur] }, []),
+            );
+        ),
+    )->subscribe($observer);
+
 =item op_ignore_elements
 
 L<https://rxjs.dev/api/operators/ignoreElements>
